@@ -7,16 +7,16 @@ print.phylopath_summary <- function(x, ...) {
 #' @export
 plot.phylopath_summary <- function(x, cut_off = 2, ...) {
   x$model <- factor(x$model, rev(x$model))
-  ggplot2::ggplot(x, ggplot2::aes_(~model, ~w, fill = ~delta_CICc < cut_off, label = ~round(p, 3))) +
+  ggplot2::ggplot(x, ggplot2::aes_(~w, ~model, fill = ~delta_CICc < cut_off, label = ~round(p, 3))) +
     ggplot2::geom_col(col = 'black', alpha = 0.6) +
     ggplot2::geom_text(hjust = "inward") +
-    ggplot2::coord_flip(expand = FALSE) +
     ggplot2::scale_fill_manual(
       values = c('TRUE' = 'firebrick', 'FALSE' = 'black'),
       labels = c('TRUE' = paste('within', cut_off, 'CICc')),
       breaks = c('TRUE')
     ) +
-    ggplot2::scale_y_continuous(position = 'top') +
+    ggplot2::scale_x_continuous(position = 'top') +
+    ggplot2::coord_cartesian(expand = FALSE) +
     ggplot2::guides(fill = ggplot2::guide_legend(title = NULL)) +
     ggplot2::labs(y = "model weight", caption = "bar labels are p-values, signficance indicates rejection") +
     ggplot2::theme(legend.position = 'bottom')
@@ -82,6 +82,10 @@ plot.DAG <- function(x, labels = NULL, algorithm = 'sugiyama', manual_layout = N
                      box_x = 12, box_y = 8, edge_width = 1.5, curvature = 0.02, rotation = 0,
                      flip_x = FALSE, flip_y = FALSE,
                      arrow = grid::arrow(type = 'closed', 18, grid::unit(15, 'points')), ...) {
+  if (sum(x) == 0) {
+    stop('This DAG has no paths to plot.')
+  }
+
   g <- igraph::graph_from_adjacency_matrix(x, weighted = TRUE)
 
   l <- ggraph::create_layout(g, 'igraph', algorithm = algorithm)
@@ -94,7 +98,7 @@ plot.DAG <- function(x, labels = NULL, algorithm = 'sugiyama', manual_layout = N
 
   ggraph::ggraph(l) +
     ggraph::geom_edge_arc(
-      curvature = curvature, arrow = arrow, edge_width = edge_width,
+      strength = curvature, arrow = arrow, edge_width = edge_width,
       end_cap = ggraph::rectangle(box_x, box_y, 'mm'),
       start_cap = ggraph::rectangle(box_x, box_y, 'mm')
     ) +
@@ -132,6 +136,9 @@ plot.fitted_DAG <- function(x, type = 'width', labels = NULL, algorithm = 'sugiy
   if (!is.null(width_const)) {
     warning('width_const has been deprecated and is ignored.', call. = FALSE)
   }
+  if (sum(x$coef) == 0) {
+    stop('This DAG has no paths to plot.')
+  }
   type <- match.arg(type, c('width', 'color', 'colour'), FALSE)
   if (type == 'colour') type <- 'color'
 
@@ -148,7 +155,7 @@ plot.fitted_DAG <- function(x, type = 'width', labels = NULL, algorithm = 'sugiy
     p <- ggplot2::ggplot(l) +
       ggraph::geom_edge_arc(
         ggplot2::aes_(width = ~abs(weight), color = ~weight < 0, label = ~round(weight, 2)),
-        curvature = curvature, arrow = arrow, end_cap = ggraph::rectangle(box_x, box_y, 'mm'),
+        strength = curvature, arrow = arrow, end_cap = ggraph::rectangle(box_x, box_y, 'mm'),
         start_cap = ggraph::rectangle(box_x, box_y, 'mm'), show.legend = show.legend,
         linejoin = c('bevel'), angle_calc = 'along', label_dodge = grid::unit(10, 'points')) +
       ggraph::geom_node_text(ggplot2::aes_(label = ~name), size = text_size) +
@@ -165,7 +172,7 @@ plot.fitted_DAG <- function(x, type = 'width', labels = NULL, algorithm = 'sugiy
       ggraph::geom_edge_arc(
         ggplot2::aes_(colour = ~weight, label = ~round(weight, 2)),
         edge_width = edge_width,
-        curvature = curvature, arrow = arrow,
+        strength = curvature, arrow = arrow,
         end_cap = ggraph::rectangle(box_x, box_y, 'mm'),
         start_cap = ggraph::rectangle(box_x, box_y, 'mm'),
         show.legend = show.legend,
@@ -367,7 +374,7 @@ plot_model_set <- function(model_set, labels = NULL, algorithm = 'kk', manual_la
 
   # Build plot.
   ggraph::ggraph(l) +
-    ggraph::geom_edge_arc(curvature = curvature, arrow = arrow, edge_width = edge_width,
+    ggraph::geom_edge_arc(strength = curvature, arrow = arrow, edge_width = edge_width,
                            end_cap = ggraph::rectangle(box_x, box_y, 'mm'),
                            start_cap = ggraph::rectangle(box_x, box_y, 'mm')) +
     ggraph::geom_node_text(ggplot2::aes_(label = ~name), size = text_size) +
